@@ -1,8 +1,7 @@
 name = "dLux"
-__version__ = "0.9.1"
+__version__ = "0.9.2"
 
 # Import as modules
-from . import base
 from . import core
 from . import detectors
 from . import optics
@@ -13,7 +12,6 @@ from . import sources
 from . import spectrums
 
 # Import core functions from modules
-from .base        import *
 from .core        import *
 from .detectors   import *
 from .optics      import *
